View source: R/eventbridge_operations.R
| eventbridge_create_connection | R Documentation |
Creates a connection. A connection defines the authorization type and credentials to use for authorization with an API destination HTTP endpoint.
See https://www.paws-r-sdk.com/docs/eventbridge_create_connection/ for full documentation.
eventbridge_create_connection(
Name,
Description = NULL,
AuthorizationType,
AuthParameters,
InvocationConnectivityParameters = NULL,
KmsKeyIdentifier = NULL
)
Name |
[required] The name for the connection to create. |
Description |
A description for the connection to create. |
AuthorizationType |
[required] The type of authorization to use for the connection. OAUTH tokens are refreshed when a 401 or 407 response is returned. |
AuthParameters |
[required] The authorization parameters to use to authorize with the endpoint. You must include only authorization parameters for the |
InvocationConnectivityParameters |
For connections to private APIs, the parameters to use for invoking the API. For more information, see Connecting to private APIs in the Amazon EventBridge User Guide . |
KmsKeyIdentifier |
The identifier of the KMS customer managed key for EventBridge to use, if you choose to use a customer managed key to encrypt this connection. The identifier can be the key Amazon Resource Name (ARN), KeyId, key alias, or key alias ARN. If you do not specify a customer managed key identifier, EventBridge uses an Amazon Web Services owned key to encrypt the connection. For more information, see Identify and view keys in the Key Management Service Developer Guide. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.