View source: R/eventbridge_operations.R
| eventbridge_update_connection | R Documentation |
Updates settings for a connection.
See https://www.paws-r-sdk.com/docs/eventbridge_update_connection/ for full documentation.
eventbridge_update_connection(
Name,
Description = NULL,
AuthorizationType = NULL,
AuthParameters = NULL,
InvocationConnectivityParameters = NULL,
KmsKeyIdentifier = NULL
)
Name |
[required] The name of the connection to update. |
Description |
A description for the connection. |
AuthorizationType |
The type of authorization to use for the connection. |
AuthParameters |
The authorization parameters to use for the connection. |
InvocationConnectivityParameters |
For connections to private APIs, the parameters to use for invoking the API. For more information, see Connecting to private APIs in the Amazon EventBridge User Guide . |
KmsKeyIdentifier |
The identifier of the KMS customer managed key for EventBridge to use, if you choose to use a customer managed key to encrypt this connection. The identifier can be the key Amazon Resource Name (ARN), KeyId, key alias, or key alias ARN. If you do not specify a customer managed key identifier, EventBridge uses an Amazon Web Services owned key to encrypt the connection. For more information, see Identify and view keys in the Key Management Service Developer Guide. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.