View source: R/locationservice_operations.R
| locationservice_calculate_route_matrix | R Documentation |
This operation is no longer current and may be deprecated in the future. We recommend you upgrade to the V2 calculate_route_matrix unless you require Grab data.
See https://www.paws-r-sdk.com/docs/locationservice_calculate_route_matrix/ for full documentation.
locationservice_calculate_route_matrix(
CalculatorName,
DeparturePositions,
DestinationPositions,
TravelMode = NULL,
DepartureTime = NULL,
DepartNow = NULL,
DistanceUnit = NULL,
CarModeOptions = NULL,
TruckModeOptions = NULL,
Key = NULL
)
CalculatorName |
[required] The name of the route calculator resource that you want to use to calculate the route matrix. |
DeparturePositions |
[required] The list of departure (origin) positions for the route matrix. An array of points, each of which is itself a 2-value array defined in WGS 84 format: Depending on the data provider selected in the route calculator resource there may be additional restrictions on the inputs you can choose. See Position restrictions in the Amazon Location Service Developer Guide. For route calculators that use Esri as the data provider, if you specify a departure that's not located on a road, Amazon Location moves the position to the nearest road. The snapped value is available in the result in Valid Values: |
DestinationPositions |
[required] The list of destination positions for the route matrix. An array of points, each of which is itself a 2-value array defined in WGS 84 format: Depending on the data provider selected in the route calculator resource there may be additional restrictions on the inputs you can choose. See Position restrictions in the Amazon Location Service Developer Guide. For route calculators that use Esri as the data provider, if you specify a destination that's not located on a road, Amazon Location moves the position to the nearest road. The snapped value is available in the result in Valid Values: |
TravelMode |
Specifies the mode of transport when calculating a route. Used in estimating the speed of travel and road compatibility. The
For more information about using Grab as a data provider, see GrabMaps in the Amazon Location Service Developer Guide. Default Value: |
DepartureTime |
Specifies the desired time of departure. Uses the given time to calculate the route matrix. You can't set both Setting a departure time in the past returns a
|
DepartNow |
Sets the time of departure as the current time. Uses the current time to calculate the route matrix. You can't set both Default Value: Valid Values: |
DistanceUnit |
Set the unit system to specify the distance. Default Value: |
CarModeOptions |
Specifies route preferences when traveling by Requirements: |
TruckModeOptions |
Specifies route preferences when traveling by Requirements: |
Key |
The optional API key to authorize the request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.