locationservice_cancel_job: CancelJob cancels a job that is currently running or pending

View source: R/locationservice_operations.R

locationservice_cancel_jobR Documentation

CancelJob cancels a job that is currently running or pending

Description

cancel_job cancels a job that is currently running or pending. If the job is already in a terminal state (Completed, Failed, or Cancelled), the operation returns successfully with the current status.

See https://www.paws-r-sdk.com/docs/locationservice_cancel_job/ for full documentation.

Usage

locationservice_cancel_job(JobId)

Arguments

JobId

[required] The unique identifier of the job to cancel.


paws.application.integration documentation built on May 30, 2026, 9:08 a.m.