Creates a geofence collection, which manages and stores geofences.
See https://www.paws-r-sdk.com/docs/locationservice_create_geofence_collection/ for full documentation.
locationservice_create_geofence_collection(
CollectionName,
PricingPlan = NULL,
PricingPlanDataSource = NULL,
Description = NULL,
Tags = NULL,
KmsKeyId = NULL
)[required] A custom name for the geofence collection.
Requirements:
Contain only alphanumeric characters (A–Z, a–z, 0–9), hyphens (-), periods (.), and underscores (_).
Must be a unique geofence collection name.
No spaces allowed. For example, ExampleGeofenceCollection.
No longer used. If included, the only allowed value is
RequestBasedUsage.
This parameter is no longer used.
An optional description for the geofence collection.
Applies one or more tags to the geofence collection. A tag is a key-value pair helps manage, identify, search, and filter your resources by labelling them.
Format: "key" : "value"
Restrictions:
Maximum 50 tags per resource
Each resource tag must be unique with a maximum of one value.
Maximum key length: 128 Unicode characters in UTF-8
Maximum value length: 256 Unicode characters in UTF-8
Can use alphanumeric characters (A–Z, a–z, 0–9), and the following characters: + - = . _ : / @.
Cannot use "aws:" as a prefix for a key.
A key identifier for an Amazon Web Services KMS customer managed key. Enter a key ID, key ARN, alias name, or alias ARN.