locationservice_create_map: This operation is no longer current and may be deprecated in...

View source: R/locationservice_operations.R

locationservice_create_mapR Documentation

This operation is no longer current and may be deprecated in the future

Description

This operation is no longer current and may be deprecated in the future. We recommend upgrading to the Maps API V2 unless you require Grab data.

See https://www.paws-r-sdk.com/docs/locationservice_create_map/ for full documentation.

Usage

locationservice_create_map(
  MapName,
  Configuration,
  PricingPlan = NULL,
  Description = NULL,
  Tags = NULL
)

Arguments

MapName

[required] The name for the map resource.

Requirements:

  • Must contain only alphanumeric characters (A–Z, a–z, 0–9), hyphens (-), periods (.), and underscores (_).

  • Must be a unique map resource name.

  • No spaces allowed. For example, ExampleMap.

Configuration

[required] Specifies the MapConfiguration, including the map style, for the map resource that you create. The map style defines the look of maps and the data provider for your map resource.

PricingPlan

No longer used. If included, the only allowed value is RequestBasedUsage.

Description

An optional description for the map resource.

Tags

Applies one or more tags to the map resource. A tag is a key-value pair helps manage, identify, search, and filter your resources by labelling them.

Format: "key" : "value"

Restrictions:

  • Maximum 50 tags per resource

  • Each resource tag must be unique with a maximum of one value.

  • Maximum key length: 128 Unicode characters in UTF-8

  • Maximum value length: 256 Unicode characters in UTF-8

  • Can use alphanumeric characters (A–Z, a–z, 0–9), and the following characters: + - = . _ : / @.

  • Cannot use "aws:" as a prefix for a key.


paws.application.integration documentation built on May 30, 2026, 9:08 a.m.