locationservice_create_place_index: This operation is no longer current and may be deprecated in...

View source: R/locationservice_operations.R

locationservice_create_place_indexR Documentation

This operation is no longer current and may be deprecated in the future

Description

This operation is no longer current and may be deprecated in the future. We recommend you upgrade to the Places API V2 unless you require Grab data.

See https://www.paws-r-sdk.com/docs/locationservice_create_place_index/ for full documentation.

Usage

locationservice_create_place_index(
  IndexName,
  DataSource,
  PricingPlan = NULL,
  Description = NULL,
  DataSourceConfiguration = NULL,
  Tags = NULL
)

Arguments

IndexName

[required] The name of the place index resource.

Requirements:

  • Contain only alphanumeric characters (A–Z, a–z, 0–9), hyphens (-), periods (.), and underscores (_).

  • Must be a unique place index resource name.

  • No spaces allowed. For example, ExamplePlaceIndex.

DataSource

[required] Specifies the geospatial data provider for the new place index.

This field is case-sensitive. Enter the valid values as shown. For example, entering HERE returns an error.

Valid values include:

For additional information , see Data providers on the Amazon Location Service developer guide.

PricingPlan

No longer used. If included, the only allowed value is RequestBasedUsage.

Description

The optional description for the place index resource.

DataSourceConfiguration

Specifies the data storage option requesting Places.

Tags

Applies one or more tags to the place index resource. A tag is a key-value pair that helps you manage, identify, search, and filter your resources.

Format: "key" : "value"

Restrictions:

  • Maximum 50 tags per resource.

  • Each tag key must be unique and must have exactly one associated value.

  • Maximum key length: 128 Unicode characters in UTF-8.

  • Maximum value length: 256 Unicode characters in UTF-8.

  • Can use alphanumeric characters (A–Z, a–z, 0–9), and the following characters: + - = . _ : / @

  • Cannot use "aws:" as a prefix for a key.


paws.application.integration documentation built on May 30, 2026, 9:08 a.m.