Creates a route calculator resource in your Amazon Web Services account.
See https://www.paws-r-sdk.com/docs/locationservice_create_route_calculator/ for full documentation.
locationservice_create_route_calculator(
CalculatorName,
DataSource,
PricingPlan = NULL,
Description = NULL,
Tags = NULL
)[required] The name of the route calculator resource.
Requirements:
Can use alphanumeric characters (A–Z, a–z, 0–9) , hyphens (-), periods (.), and underscores (_).
Must be a unique Route calculator resource name.
No spaces allowed. For example, ExampleRouteCalculator.
[required] Specifies the data provider of traffic and road network data.
This field is case-sensitive. Enter the valid values as shown. For
example, entering HERE returns an error.
Valid values include:
Esri – For additional information about
Esri's
coverage in your region of interest, see Esri details on street networks and traffic coverage.
Route calculators that use Esri as a data source only calculate routes that are shorter than 400 km.
Grab – Grab provides routing functionality for Southeast Asia. For
additional information about
GrabMaps'
coverage, see GrabMaps countries and areas covered.
Here – For additional information about HERE Technologies'
coverage in your region of interest, see HERE car routing coverage and HERE truck routing coverage.
For additional information , see Data providers on the Amazon Location Service Developer Guide.
No longer used. If included, the only allowed value is
RequestBasedUsage.
The optional description for the route calculator resource.
Applies one or more tags to the route calculator resource. A tag is a key-value pair helps manage, identify, search, and filter your resources by labelling them.
For example: { "tag1" : "value1", "tag2" : "value2"}
Format: "key" : "value"
Restrictions:
Maximum 50 tags per resource
Each resource tag must be unique with a maximum of one value.
Maximum key length: 128 Unicode characters in UTF-8
Maximum value length: 256 Unicode characters in UTF-8
Can use alphanumeric characters (A–Z, a–z, 0–9), and the following characters: + - = . _ : / @.
Cannot use "aws:" as a prefix for a key.