locationservice_delete_map: This operation is no longer current and may be deprecated in...

View source: R/locationservice_operations.R

locationservice_delete_mapR Documentation

This operation is no longer current and may be deprecated in the future

Description

This operation is no longer current and may be deprecated in the future. We recommend upgrading to the Maps API V2 unless you require Grab data.

See https://www.paws-r-sdk.com/docs/locationservice_delete_map/ for full documentation.

Usage

locationservice_delete_map(MapName)

Arguments

MapName

[required] The name of the map resource to be deleted.


paws.application.integration documentation built on May 30, 2026, 9:08 a.m.