locationservice_delete_route_calculator: This operation is no longer current and may be deprecated in...

View source: R/locationservice_operations.R

locationservice_delete_route_calculatorR Documentation

This operation is no longer current and may be deprecated in the future

Description

This operation is no longer current and may be deprecated in the future. We recommend you upgrade to the Routes API V2 unless you require Grab data.

See https://www.paws-r-sdk.com/docs/locationservice_delete_route_calculator/ for full documentation.

Usage

locationservice_delete_route_calculator(CalculatorName)

Arguments

CalculatorName

[required] The name of the route calculator resource to be deleted.


paws.application.integration documentation built on May 30, 2026, 9:08 a.m.