locationservice_forecast_geofence_events: This action forecasts future geofence events that are likely...

View source: R/locationservice_operations.R

locationservice_forecast_geofence_eventsR Documentation

This action forecasts future geofence events that are likely to occur within a specified time horizon if a device continues moving at its current speed

Description

This action forecasts future geofence events that are likely to occur within a specified time horizon if a device continues moving at its current speed. Each forecasted event is associated with a geofence from a provided geofence collection. A forecast event can have one of the following states:

See https://www.paws-r-sdk.com/docs/locationservice_forecast_geofence_events/ for full documentation.

Usage

locationservice_forecast_geofence_events(
  CollectionName,
  DeviceState,
  TimeHorizonMinutes = NULL,
  DistanceUnit = NULL,
  SpeedUnit = NULL,
  NextToken = NULL,
  MaxResults = NULL
)

Arguments

CollectionName

[required] The name of the geofence collection.

DeviceState

[required] Represents the device's state, including its current position and speed. When speed is omitted, this API performs a containment check. The containment check operation returns IDLE events for geofences where the device is currently inside of, but no other events.

TimeHorizonMinutes

The forward-looking time window for forecasting, specified in minutes. The API only returns events that are predicted to occur within this time horizon. When no value is specified, this API performs a containment check. The containment check operation returns IDLE events for geofences where the device is currently inside of, but no other events.

DistanceUnit

The distance unit used for the NearestDistance property returned in a forecasted event. The measurement system must match for DistanceUnit and SpeedUnit; if Kilometers is specified for DistanceUnit, then SpeedUnit must be KilometersPerHour.

Default Value: Kilometers

SpeedUnit

The speed unit for the device captured by the device state. The measurement system must match for DistanceUnit and SpeedUnit; if Kilometers is specified for DistanceUnit, then SpeedUnit must be KilometersPerHour.

Default Value: KilometersPerHour.

NextToken

The pagination token specifying which page of results to return in the response. If no token is provided, the default page is the first page.

Default value: null

MaxResults

An optional limit for the number of resources returned in a single call.

Default value: 20


paws.application.integration documentation built on May 30, 2026, 9:08 a.m.