locationservice_get_map_sprites: This operation is no longer current and may be deprecated in...

View source: R/locationservice_operations.R

locationservice_get_map_spritesR Documentation

This operation is no longer current and may be deprecated in the future

Description

This operation is no longer current and may be deprecated in the future. We recommend upgrading to GetSprites unless you require Grab data.

See https://www.paws-r-sdk.com/docs/locationservice_get_map_sprites/ for full documentation.

Usage

locationservice_get_map_sprites(MapName, FileName, Key = NULL)

Arguments

MapName

[required] The map resource associated with the sprite file.

FileName

[required] The name of the sprite file. Use the following file names for the sprite sheet:

  • sprites.png

  • ⁠sprites@2x.png⁠ for high pixel density displays

For the JSON document containing image offsets. Use the following file names:

  • sprites.json

  • ⁠sprites@2x.json⁠ for high pixel density displays

Key

The optional API key to authorize the request.


paws.application.integration documentation built on May 30, 2026, 9:08 a.m.