locationservice_get_map_style_descriptor: This operation is no longer current and may be deprecated in...

View source: R/locationservice_operations.R

locationservice_get_map_style_descriptorR Documentation

This operation is no longer current and may be deprecated in the future

Description

This operation is no longer current and may be deprecated in the future. We recommend upgrading to GetStyleDescriptor unless you require Grab data.

See https://www.paws-r-sdk.com/docs/locationservice_get_map_style_descriptor/ for full documentation.

Usage

locationservice_get_map_style_descriptor(MapName, Key = NULL)

Arguments

MapName

[required] The map resource to retrieve the style descriptor from.

Key

The optional API key to authorize the request.


paws.application.integration documentation built on May 30, 2026, 9:08 a.m.