locationservice_get_map_tile: This operation is no longer current and may be deprecated in...

View source: R/locationservice_operations.R

locationservice_get_map_tileR Documentation

This operation is no longer current and may be deprecated in the future

Description

This operation is no longer current and may be deprecated in the future. We recommend upgrading to GetTile unless you require Grab data.

See https://www.paws-r-sdk.com/docs/locationservice_get_map_tile/ for full documentation.

Usage

locationservice_get_map_tile(MapName, Z, X, Y, Key = NULL)

Arguments

MapName

[required] The map resource to retrieve the map tiles from.

Z

[required] The zoom value for the map tile.

X

[required] The X axis value for the map tile.

Y

[required] The Y axis value for the map tile.

Key

The optional API key to authorize the request.


paws.application.integration documentation built on May 30, 2026, 9:08 a.m.