locationservice_list_jobs: ListJobs retrieves a list of jobs with optional filtering and...

View source: R/locationservice_operations.R

locationservice_list_jobsR Documentation

ListJobs retrieves a list of jobs with optional filtering and pagination support

Description

list_jobs retrieves a list of jobs with optional filtering and pagination support.

See https://www.paws-r-sdk.com/docs/locationservice_list_jobs/ for full documentation.

Usage

locationservice_list_jobs(Filter = NULL, MaxResults = NULL, NextToken = NULL)

Arguments

Filter

An optional structure containing criteria by which to filter job results.

MaxResults

Maximum number of jobs to return.

NextToken

The pagination token specifying which page of results to return in the response. If no token is provided, the default page is the first page.


paws.application.integration documentation built on May 30, 2026, 9:08 a.m.