locationservice_list_maps: This operation is no longer current and may be deprecated in...

View source: R/locationservice_operations.R

locationservice_list_mapsR Documentation

This operation is no longer current and may be deprecated in the future

Description

This operation is no longer current and may be deprecated in the future. We recommend upgrading to the Maps API V2 unless you require Grab data.

See https://www.paws-r-sdk.com/docs/locationservice_list_maps/ for full documentation.

Usage

locationservice_list_maps(MaxResults = NULL, NextToken = NULL)

Arguments

MaxResults

An optional limit for the number of resources returned in a single call.

Default value: 100

NextToken

The pagination token specifying which page of results to return in the response. If no token is provided, the default page is the first page.

Default value: null


paws.application.integration documentation built on May 30, 2026, 9:08 a.m.