View source: R/locationservice_operations.R
| locationservice_search_place_index_for_suggestions | R Documentation |
This operation is no longer current and may be deprecated in the future. We recommend you upgrade to Suggest or Autocomplete unless you require Grab data.
See https://www.paws-r-sdk.com/docs/locationservice_search_place_index_for_suggestions/ for full documentation.
locationservice_search_place_index_for_suggestions(
IndexName,
Text,
BiasPosition = NULL,
FilterBBox = NULL,
FilterCountries = NULL,
MaxResults = NULL,
Language = NULL,
FilterCategories = NULL,
Key = NULL
)
IndexName |
[required] The name of the place index resource you want to use for the search. |
Text |
[required] The free-form partial text to use to generate place suggestions. For example, |
BiasPosition |
An optional parameter that indicates a preference for place suggestions that are closer to a specified position. If provided, this parameter must contain a pair of numbers. The first number represents the X coordinate, or longitude; the second number represents the Y coordinate, or latitude. For example,
|
FilterBBox |
An optional parameter that limits the search results by returning only suggestions within a specified bounding box. If provided, this parameter must contain a total of four consecutive numbers in two pairs. The first pair of numbers represents the X and Y coordinates (longitude and latitude, respectively) of the southwest corner of the bounding box; the second pair of numbers represents the X and Y coordinates (longitude and latitude, respectively) of the northeast corner of the bounding box. For example,
|
FilterCountries |
An optional parameter that limits the search results by returning only suggestions within the provided list of countries.
|
MaxResults |
An optional parameter. The maximum number of results returned per request. The default: |
Language |
The preferred language used to return results. The value must be a valid BCP 47 language tag, for example, This setting affects the languages used in the results. If no language is specified, or not supported for a particular result, the partner automatically chooses a language for the result. For an example, we'll use the Greek language. You search for If you set the If the data provider does not have a value for Greek, the result will be in a language that the provider does support. |
FilterCategories |
A list of one or more Amazon Location categories to filter the returned places. If you include more than one category, the results will include results that match any of the categories listed. For more information about using categories, including a list of Amazon Location categories, see Categories and filtering, in the Amazon Location Service developer guide. |
Key |
The optional API key to authorize the request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.