locationservice_start_job: StartJob starts a new asynchronous bulk processing job

View source: R/locationservice_operations.R

locationservice_start_jobR Documentation

StartJob starts a new asynchronous bulk processing job

Description

start_job starts a new asynchronous bulk processing job. You specify the input data location in Amazon S3, the action to perform, and the output location where results are written.

See https://www.paws-r-sdk.com/docs/locationservice_start_job/ for full documentation.

Usage

locationservice_start_job(
  ClientToken = NULL,
  Action,
  ActionOptions = NULL,
  ExecutionRoleArn,
  InputOptions,
  Name = NULL,
  OutputOptions,
  Tags = NULL
)

Arguments

ClientToken

A unique identifier for this request to ensure idempotency.

Action

[required] The action to perform on the input data.

ActionOptions

Additional parameters that can be requested for each result.

ExecutionRoleArn

[required] The Amazon Resource Name (ARN) of the IAM role that Amazon Location Service assumes during job processing. Amazon Location Service uses this role to access the input and output locations specified for the job.

The IAM role must be created in the same Amazon Web Services account where you plan to run your job.

For more information about configuring IAM roles for Amazon Location jobs, see Configure IAM permissions in the Amazon Location Service Developer Guide.

InputOptions

[required] Configuration for input data location and format.

Input files have a limitation of 10gb per file, and 1gb per Parquet row-group within the file.

Name

An optional name for the job resource.

OutputOptions

[required] Configuration for output data location and format.

Tags

Tags and corresponding values to be associated with the job.


paws.application.integration documentation built on May 30, 2026, 9:08 a.m.