locationservice_update_map: This operation is no longer current and may be deprecated in...

View source: R/locationservice_operations.R

locationservice_update_mapR Documentation

This operation is no longer current and may be deprecated in the future

Description

This operation is no longer current and may be deprecated in the future. We recommend upgrading to the Maps API V2 unless you require Grab data.

See https://www.paws-r-sdk.com/docs/locationservice_update_map/ for full documentation.

Usage

locationservice_update_map(
  MapName,
  PricingPlan = NULL,
  Description = NULL,
  ConfigurationUpdate = NULL
)

Arguments

MapName

[required] The name of the map resource to update.

PricingPlan

No longer used. If included, the only allowed value is RequestBasedUsage.

Description

Updates the description for the map resource.

ConfigurationUpdate

Updates the parts of the map configuration that can be updated, including the political view.


paws.application.integration documentation built on May 30, 2026, 9:08 a.m.