locationservice_update_place_index: This operation is no longer current and may be deprecated in...

View source: R/locationservice_operations.R

locationservice_update_place_indexR Documentation

This operation is no longer current and may be deprecated in the future

Description

This operation is no longer current and may be deprecated in the future. We recommend you upgrade to the Places API V2 unless you require Grab data.

See https://www.paws-r-sdk.com/docs/locationservice_update_place_index/ for full documentation.

Usage

locationservice_update_place_index(
  IndexName,
  PricingPlan = NULL,
  Description = NULL,
  DataSourceConfiguration = NULL
)

Arguments

IndexName

[required] The name of the place index resource to update.

PricingPlan

No longer used. If included, the only allowed value is RequestBasedUsage.

Description

Updates the description for the place index resource.

DataSourceConfiguration

Updates the data storage option for the place index resource.


paws.application.integration documentation built on May 30, 2026, 9:08 a.m.