Updates the specified properties of a given place index resource.
See https://www.paws-r-sdk.com/docs/locationservice_update_place_index/ for full documentation.
locationservice_update_place_index(
IndexName,
PricingPlan = NULL,
Description = NULL,
DataSourceConfiguration = NULL
)[required] The name of the place index resource to update.
No longer used. If included, the only allowed value is
RequestBasedUsage.
Updates the description for the place index resource.
Updates the data storage option for the place index resource.