View source: R/mwaa_operations.R
| mwaa_create_environment | R Documentation |
Creates an Amazon Managed Workflows for Apache Airflow (Amazon MWAA) environment.
See https://www.paws-r-sdk.com/docs/mwaa_create_environment/ for full documentation.
mwaa_create_environment(
Name,
ExecutionRoleArn,
SourceBucketArn,
DagS3Path,
NetworkConfiguration,
PluginsS3Path = NULL,
PluginsS3ObjectVersion = NULL,
RequirementsS3Path = NULL,
RequirementsS3ObjectVersion = NULL,
StartupScriptS3Path = NULL,
StartupScriptS3ObjectVersion = NULL,
AirflowConfigurationOptions = NULL,
EnvironmentClass = NULL,
MaxWorkers = NULL,
KmsKey = NULL,
AirflowVersion = NULL,
LoggingConfiguration = NULL,
WeeklyMaintenanceWindowStart = NULL,
Tags = NULL,
WebserverAccessMode = NULL,
MinWorkers = NULL,
Schedulers = NULL,
EndpointManagement = NULL,
MinWebservers = NULL,
MaxWebservers = NULL
)
Name |
[required] The name of the Amazon MWAA environment. For example, |
ExecutionRoleArn |
[required] The Amazon Resource Name (ARN) of the execution role for your environment. An execution role is an Amazon Web Services Identity and Access Management (IAM) role that grants MWAA permission to access Amazon Web Services services and resources used by your environment. For example, |
SourceBucketArn |
[required] The Amazon Resource Name (ARN) of the Amazon S3 bucket where your DAG code and supporting files are stored. For example, |
DagS3Path |
[required] The relative path to the DAGs folder on your Amazon S3 bucket. For example, |
NetworkConfiguration |
[required] The VPC networking components used to secure and enable network traffic between the Amazon Web Services resources for your environment. For more information, refer to About networking on Amazon MWAA. |
PluginsS3Path |
The relative path to the |
PluginsS3ObjectVersion |
The version of the plugins.zip file on your Amazon S3 bucket. You must specify a version each time a plugins.zip file is updated. For more information, refer to How S3 Versioning works. |
RequirementsS3Path |
The relative path to the |
RequirementsS3ObjectVersion |
The version of the |
StartupScriptS3Path |
The relative path to the startup shell script in your Amazon S3 bucket. For example, Amazon MWAA runs the script as your environment starts, and before running the Apache Airflow process. You can use this script to install dependencies, modify Apache Airflow configuration options, and set environment variables. For more information, refer to Using a startup script. |
StartupScriptS3ObjectVersion |
The version of the startup shell script in your Amazon S3 bucket. You must specify the version ID that Amazon S3 assigns to the file every time you update the script. Version IDs are Unicode, UTF-8 encoded, URL-ready, opaque strings that are no more than 1,024 bytes long. The following is an example:
For more information, refer to Using a startup script. |
AirflowConfigurationOptions |
A list of key-value pairs containing the Apache Airflow configuration options you want to attach to your environment. For more information, refer to Apache Airflow configuration options. |
EnvironmentClass |
The environment class type. Valid values: |
MaxWorkers |
The maximum number of workers that you want to run in your environment. MWAA scales the number of Apache Airflow workers up to the number you specify in the |
KmsKey |
The Amazon Web Services Key Management Service (KMS) key to encrypt the data in your environment. You can use an Amazon Web Services owned CMK, or a Customer managed CMK (advanced). For more information, refer to Create an Amazon MWAA environment. |
AirflowVersion |
The Apache Airflow version for your environment. If no value is specified, it defaults to the latest version. For more information, refer to Apache Airflow versions on Amazon Managed Workflows for Apache Airflow (Amazon MWAA). Valid values: |
LoggingConfiguration |
Defines the Apache Airflow logs to send to CloudWatch Logs. |
WeeklyMaintenanceWindowStart |
The day and time of the week in Coordinated Universal Time (UTC) 24-hour standard time to start weekly maintenance updates of your environment in the following format: |
Tags |
The key-value tag pairs you want to associate to your environment. For example, |
WebserverAccessMode |
Defines the access mode for the Apache Airflow web server. For more information, refer to Apache Airflow access modes. If set to |
MinWorkers |
The minimum number of workers that you want to run in your environment. MWAA scales the number of Apache Airflow workers up to the number you specify in the |
Schedulers |
The number of Apache Airflow schedulers to run in your environment. Valid values:
|
EndpointManagement |
Defines whether the VPC endpoints configured for the environment are created, and managed, by the customer or by Amazon MWAA. If set to |
MinWebservers |
The minimum number of web servers that you want to run in your environment. Amazon MWAA scales the number of Apache Airflow web servers up to the number you specify for Valid values: For environments larger than mw1.micro, accepts values from |
MaxWebservers |
The maximum number of web servers that you want to run in your environment. Amazon MWAA scales the number of Apache Airflow web servers up to the number you specify for Valid values: For environments larger than mw1.micro, accepts values from |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.