resourceexplorer_delete_resource_explorer_setup: Deletes a Resource Explorer setup configuration

View source: R/resourceexplorer_operations.R

resourceexplorer_delete_resource_explorer_setupR Documentation

Deletes a Resource Explorer setup configuration

Description

Deletes a Resource Explorer setup configuration. This operation removes indexes and views from the specified Regions or all Regions where Resource Explorer is configured.

See https://www.paws-r-sdk.com/docs/resourceexplorer_delete_resource_explorer_setup/ for full documentation.

Usage

resourceexplorer_delete_resource_explorer_setup(
  RegionList = NULL,
  DeleteInAllRegions = NULL
)

Arguments

RegionList

A list of Amazon Web Services Regions from which to delete the Resource Explorer configuration. If not specified, the operation uses the DeleteInAllRegions parameter to determine scope.

DeleteInAllRegions

Specifies whether to delete Resource Explorer configuration from all Regions where it is currently enabled. If this parameter is set to true, a value for RegionList must not be provided. Otherwise, the operation fails with a ValidationException error.


paws.application.integration documentation built on May 30, 2026, 9:08 a.m.