resourceexplorer_get_resource_explorer_setup: Retrieves the status and details of a Resource Explorer setup...

View source: R/resourceexplorer_operations.R

resourceexplorer_get_resource_explorer_setupR Documentation

Retrieves the status and details of a Resource Explorer setup operation

Description

Retrieves the status and details of a Resource Explorer setup operation. This operation returns information about the progress of creating or deleting Resource Explorer configurations across Regions.

See https://www.paws-r-sdk.com/docs/resourceexplorer_get_resource_explorer_setup/ for full documentation.

Usage

resourceexplorer_get_resource_explorer_setup(
  TaskId,
  MaxResults = NULL,
  NextToken = NULL
)

Arguments

TaskId

[required] The unique identifier of the setup task to retrieve status information for. This ID is returned by create_resource_explorer_setup or delete_resource_explorer_setup operations.

MaxResults

The maximum number of Region status results to return in a single response. Valid values are between 1 and 100.

NextToken

The pagination token from a previous get_resource_explorer_setup response. Use this token to retrieve the next set of results.


paws.application.integration documentation built on May 30, 2026, 9:08 a.m.