resourceexplorer_get_service_index: Retrieves information about the Resource Explorer index in...

View source: R/resourceexplorer_operations.R

resourceexplorer_get_service_indexR Documentation

Retrieves information about the Resource Explorer index in the current Amazon Web Services Region

Description

Retrieves information about the Resource Explorer index in the current Amazon Web Services Region. This operation returns the ARN and type of the index if one exists.

See https://www.paws-r-sdk.com/docs/resourceexplorer_get_service_index/ for full documentation.

Usage

resourceexplorer_get_service_index()

paws.application.integration documentation built on May 30, 2026, 9:08 a.m.