resourceexplorer_get_service_view: Retrieves details about a specific Resource Explorer service...

View source: R/resourceexplorer_operations.R

resourceexplorer_get_service_viewR Documentation

Retrieves details about a specific Resource Explorer service view

Description

Retrieves details about a specific Resource Explorer service view. This operation returns the configuration and properties of the specified view.

See https://www.paws-r-sdk.com/docs/resourceexplorer_get_service_view/ for full documentation.

Usage

resourceexplorer_get_service_view(ServiceViewArn)

Arguments

ServiceViewArn

[required] The Amazon Resource Name (ARN) of the service view to retrieve details for.


paws.application.integration documentation built on May 30, 2026, 9:08 a.m.