View source: R/resourceexplorer_operations.R
| resourceexplorer_list_indexes | R Documentation |
Retrieves a list of all of the indexes in Amazon Web Services Regions that are currently collecting resource information for Amazon Web Services Resource Explorer.
See https://www.paws-r-sdk.com/docs/resourceexplorer_list_indexes/ for full documentation.
resourceexplorer_list_indexes(
Type = NULL,
Regions = NULL,
MaxResults = NULL,
NextToken = NULL
)
Type |
If specified, limits the output to only indexes of the specified Type, either Use this option to discover the aggregator index for your account. |
Regions |
If specified, limits the response to only information about the index in the specified list of Amazon Web Services Regions. |
MaxResults |
The maximum number of results that you want included on each page of the response. If you do not include this parameter, it defaults to a value appropriate to the operation. If additional items exist beyond those included in the current response, the An API operation can return fewer results than the maximum even when there are more results available. You should check |
NextToken |
The parameter for receiving additional results if you receive a |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.