resourceexplorer_list_service_indexes: Lists all Resource Explorer indexes across the specified...

View source: R/resourceexplorer_operations.R

resourceexplorer_list_service_indexesR Documentation

Lists all Resource Explorer indexes across the specified Amazon Web Services Regions

Description

Lists all Resource Explorer indexes across the specified Amazon Web Services Regions. This operation returns information about indexes including their ARNs, types, and Regions.

See https://www.paws-r-sdk.com/docs/resourceexplorer_list_service_indexes/ for full documentation.

Usage

resourceexplorer_list_service_indexes(
  Regions = NULL,
  MaxResults = NULL,
  NextToken = NULL
)

Arguments

Regions

A list of Amazon Web Services Regions to include in the search for indexes. If not specified, indexes from all Regions are returned.

MaxResults

The maximum number of index results to return in a single response. Valid values are between 1 and 100.

NextToken

The pagination token from a previous list_service_indexes response. Use this token to retrieve the next set of results.


paws.application.integration documentation built on May 30, 2026, 9:08 a.m.