resourceexplorer_list_service_views: Lists all Resource Explorer service views available in the...

View source: R/resourceexplorer_operations.R

resourceexplorer_list_service_viewsR Documentation

Lists all Resource Explorer service views available in the current Amazon Web Services account

Description

Lists all Resource Explorer service views available in the current Amazon Web Services account. This operation returns the ARNs of available service views.

See https://www.paws-r-sdk.com/docs/resourceexplorer_list_service_views/ for full documentation.

Usage

resourceexplorer_list_service_views(MaxResults = NULL, NextToken = NULL)

Arguments

MaxResults

The maximum number of service view results to return in a single response. Valid values are between 1 and 50.

NextToken

The pagination token from a previous list_service_views response. Use this token to retrieve the next set of results.


paws.application.integration documentation built on May 30, 2026, 9:08 a.m.