View source: R/resourceexplorer_operations.R
| resourceexplorer_list_views | R Documentation |
Lists the Amazon resource names (ARNs) of the views available in the Amazon Web Services Region in which you call this operation.
See https://www.paws-r-sdk.com/docs/resourceexplorer_list_views/ for full documentation.
resourceexplorer_list_views(NextToken = NULL, MaxResults = NULL)
NextToken |
The parameter for receiving additional results if you receive a |
MaxResults |
The maximum number of results that you want included on each page of the response. If you do not include this parameter, it defaults to a value appropriate to the operation. If additional items exist beyond those included in the current response, the An API operation can return fewer results than the maximum even when there are more results available. You should check |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.