View source: R/resourceexplorer_operations.R
| resourceexplorer_search | R Documentation |
Searches for resources and displays details about all resources that match the specified criteria. You must specify a query string.
See https://www.paws-r-sdk.com/docs/resourceexplorer_search/ for full documentation.
resourceexplorer_search(
QueryString,
MaxResults = NULL,
ViewArn = NULL,
NextToken = NULL
)
QueryString |
[required] A string that includes keywords and filters that specify the resources that you want to include in the results. For the complete syntax supported by the The search is completely case insensitive. You can specify an empty string to return all results up to the limit of 1,000 total results. The operation can return only the first 1,000 results. If the resource you want is not included, then use a different value for |
MaxResults |
The maximum number of results that you want included on each page of the response. If you do not include this parameter, it defaults to a value appropriate to the operation. If additional items exist beyond those included in the current response, the An API operation can return fewer results than the maximum even when there are more results available. You should check |
ViewArn |
Specifies the Amazon resource name (ARN) of the view to use for the query. If you don't specify a value for this parameter, then the operation automatically uses the default view for the Amazon Web Services Region in which you called this operation. If the Region either doesn't have a default view or if you don't have permission to use the default view, then the operation fails with a |
NextToken |
The parameter for receiving additional results if you receive a |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.