View source: R/sfn_operations.R
| sfn_test_state | R Documentation |
Accepts the definition of a single state and executes it. You can test a state without creating a state machine or updating an existing state machine. Using this API, you can test the following:
See https://www.paws-r-sdk.com/docs/sfn_test_state/ for full documentation.
sfn_test_state(
definition,
roleArn = NULL,
input = NULL,
inspectionLevel = NULL,
revealSecrets = NULL,
variables = NULL,
stateName = NULL,
mock = NULL,
context = NULL,
stateConfiguration = NULL
)
definition |
[required] The Amazon States Language (ASL) definition of the state or state machine. |
roleArn |
The Amazon Resource Name (ARN) of the execution role with the required IAM permissions for the state. |
input |
A string that contains the JSON input data for the state. |
inspectionLevel |
Determines the values to return when a state is tested. You can specify one of the following types:
Each of these levels also provide information about the status of the state execution and the next state to transition to. |
revealSecrets |
Specifies whether or not to include secret information in the test result. For HTTP Tasks, a secret includes the data that an EventBridge connection adds to modify the HTTP request headers, query parameters, and body. Step Functions doesn't omit any information included in the state definition or the HTTP response. If you set By default, |
variables |
JSON object literal that sets variables used in the state under test. Object keys are the variable names and values are the variable values. |
stateName |
Denotes the particular state within a state machine definition to be tested. If this field is specified, the |
mock |
Defines a mocked result or error for the state under test. A mock can only be specified for Task, Map, or Parallel states. If it is specified for another state type, an exception will be thrown. |
context |
A JSON string representing a valid Context object for the state under test. This field may only be specified if a mock is specified in the same request. |
stateConfiguration |
Contains configurations for the state under test. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.