sns_publish_batch: Publishes up to 10 messages to the specified topic in a...

View source: R/sns_operations.R

sns_publish_batchR Documentation

Publishes up to 10 messages to the specified topic in a single batch

Description

Publishes up to 10 messages to the specified topic in a single batch. This is a batch version of the publish API. If you try to send more than 10 messages in a single batch request, you will receive a TooManyEntriesInBatchRequest exception.

See https://www.paws-r-sdk.com/docs/sns_publish_batch/ for full documentation.

Usage

sns_publish_batch(TopicArn, PublishBatchRequestEntries)

Arguments

TopicArn

[required] The Amazon resource name (ARN) of the topic you want to batch publish to.

PublishBatchRequestEntries

[required] A list of publish_batch request entries to be sent to the SNS topic.


paws.application.integration documentation built on May 30, 2026, 9:08 a.m.