Add tags to the specified Amazon SNS topic. For an overview, see Amazon SNS Tags in the Amazon SNS Developer Guide.
sns_tag_resource(ResourceArn, Tags)[required] The ARN of the topic to which to add tags.
[required] The tags to be added to the specified topic. A tag consists of a required key and an optional value.
svc$tag_resource(
ResourceArn = "string",
Tags = list(
list(
Key = "string",
Value = "string"
)
)
)
When you use topic tags, keep the following guidelines in mind:
Adding more than 50 tags to a topic isn\'t recommended.
Tags don\'t have any semantic meaning. Amazon SNS interprets tags as character strings.
Tags are case-sensitive.
A new tag with a key identical to that of an existing tag overwrites the existing tag.
Tagging actions are limited to 10 TPS per AWS account, per AWS region. If your application requires a higher throughput, file a technical support request.