View source: R/sqs_operations.R
| sqs_send_message | R Documentation |
Delivers a message to the specified queue.
See https://www.paws-r-sdk.com/docs/sqs_send_message/ for full documentation.
sqs_send_message(
QueueUrl,
MessageBody,
DelaySeconds = NULL,
MessageAttributes = NULL,
MessageSystemAttributes = NULL,
MessageDeduplicationId = NULL,
MessageGroupId = NULL
)
QueueUrl |
[required] The URL of the Amazon SQS queue to which a message is sent. Queue URLs and names are case-sensitive. |
MessageBody |
[required] The message to send. The minimum size is one character. The maximum size is 1 MiB or 1,048,576 bytes A message can include only XML, JSON, and unformatted text. The following Unicode characters are allowed. For more information, see the W3C specification for characters.
If a message contains characters outside the allowed set, Amazon SQS rejects the message and returns an InvalidMessageContents error. Ensure that your message body includes only valid characters to avoid this exception. |
DelaySeconds |
The length of time, in seconds, for which to delay a specific message. Valid values: 0 to 900. Maximum: 15 minutes. Messages with a positive When you set |
MessageAttributes |
Each message attribute consists of a |
MessageSystemAttributes |
The message system attribute to send. Each message system attribute consists of a
|
MessageDeduplicationId |
This parameter applies only to FIFO (first-in-first-out) queues. The token used for deduplication of sent messages. If a message with a particular
The If a message is sent successfully but the acknowledgement is lost and the message is resent with the same Amazon SQS continues to keep track of the message deduplication ID even after the message is received and deleted. The maximum length of For best practices of using []: R:%5C [Using the MessageDeduplicationId Property]: R:Using%20the%20MessageDeduplicationId%20Property |
MessageGroupId |
The length of For best practices of using []: R:%5C [Using the MessageGroupId Property]: R:Using%20the%20MessageGroupId%20Property |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.