View source: R/swf_operations.R
| swf_register_workflow_type | R Documentation |
Registers a new workflow type and its configuration settings in the specified domain.
See https://www.paws-r-sdk.com/docs/swf_register_workflow_type/ for full documentation.
swf_register_workflow_type(
domain,
name,
version,
description = NULL,
defaultTaskStartToCloseTimeout = NULL,
defaultExecutionStartToCloseTimeout = NULL,
defaultTaskList = NULL,
defaultTaskPriority = NULL,
defaultChildPolicy = NULL,
defaultLambdaRole = NULL
)
domain |
[required] The name of the domain in which to register the workflow type. |
name |
[required] The name of the workflow type. The specified string must not contain a |
version |
[required] The version of the workflow type. The workflow type consists of the name and version, the combination of which must be unique within the domain. To get a list of all currently registered workflow types, use the The specified string must not contain a |
description |
Textual description of the workflow type. |
defaultTaskStartToCloseTimeout |
If set, specifies the default maximum duration of decision tasks for this workflow type. This default can be overridden when starting a workflow execution using the The duration is specified in seconds, an integer greater than or equal to |
defaultExecutionStartToCloseTimeout |
If set, specifies the default maximum duration for executions of this workflow type. You can override this default when starting an execution through the The duration is specified in seconds; an integer greater than or equal to 0. Unlike some of the other timeout parameters in Amazon SWF, you cannot specify a value of "NONE" for |
defaultTaskList |
If set, specifies the default task list to use for scheduling decision tasks for executions of this workflow type. This default is used only if a task list isn't provided when starting the execution through the |
defaultTaskPriority |
The default task priority to assign to the workflow type. If not assigned, then For more information about setting task priority, see Setting Task Priority in the Amazon SWF Developer Guide. |
defaultChildPolicy |
If set, specifies the default policy to use for the child workflow executions when a workflow execution of this type is terminated, by calling the The supported child policies are:
|
defaultLambdaRole |
The default IAM role attached to this workflow type. Executions of this workflow type need IAM roles to invoke Lambda functions. If you don't specify an IAM role when you start this workflow type, the default Lambda role is attached to the execution. For more information, see https://docs.aws.amazon.com/amazonswf/latest/developerguide/lambda-task.html in the Amazon SWF Developer Guide. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.