View source: R/eventbridge_operations.R
| eventbridge_update_archive | R Documentation |
Updates the specified archive.
See https://www.paws-r-sdk.com/docs/eventbridge_update_archive/ for full documentation.
eventbridge_update_archive(
ArchiveName,
Description = NULL,
EventPattern = NULL,
RetentionDays = NULL,
KmsKeyIdentifier = NULL
)
ArchiveName |
[required] The name of the archive to update. |
Description |
The description for the archive. |
EventPattern |
The event pattern to use to filter events sent to the archive. |
RetentionDays |
The number of days to retain events in the archive. |
KmsKeyIdentifier |
The identifier of the KMS customer managed key for EventBridge to use, if you choose to use a customer managed key to encrypt this archive. The identifier can be the key Amazon Resource Name (ARN), KeyId, key alias, or key alias ARN. If you do not specify a customer managed key identifier, EventBridge uses an Amazon Web Services owned key to encrypt the archive. For more information, see Identify and view keys in the Key Management Service Developer Guide. If you have specified that EventBridge use a customer managed key for encrypting the source event bus, we strongly recommend you also specify a customer managed key for any archives for the event bus as well. For more information, see Encrypting archives in the Amazon EventBridge User Guide. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.