View source: R/locationservice_operations.R
| locationservice_cancel_job | R Documentation |
cancel_job cancels a job that is currently running or pending. If the job is already in a terminal state (Completed, Failed, or Cancelled), the operation returns successfully with the current status.
See https://www.paws-r-sdk.com/docs/locationservice_cancel_job/ for full documentation.
locationservice_cancel_job(JobId)
JobId |
[required] The unique identifier of the job to cancel. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.