View source: R/locationservice_operations.R
| locationservice_create_map | R Documentation |
This operation is no longer current and may be deprecated in the future. We recommend upgrading to the Maps API V2 unless you require Grab data.
See https://www.paws-r-sdk.com/docs/locationservice_create_map/ for full documentation.
locationservice_create_map(
MapName,
Configuration,
PricingPlan = NULL,
Description = NULL,
Tags = NULL
)
MapName |
[required] The name for the map resource. Requirements:
|
Configuration |
[required] Specifies the |
PricingPlan |
No longer used. If included, the only allowed value is |
Description |
An optional description for the map resource. |
Tags |
Applies one or more tags to the map resource. A tag is a key-value pair helps manage, identify, search, and filter your resources by labelling them. Format: Restrictions:
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.