View source: R/locationservice_operations.R
| locationservice_create_place_index | R Documentation |
This operation is no longer current and may be deprecated in the future. We recommend you upgrade to the Places API V2 unless you require Grab data.
See https://www.paws-r-sdk.com/docs/locationservice_create_place_index/ for full documentation.
locationservice_create_place_index(
IndexName,
DataSource,
PricingPlan = NULL,
Description = NULL,
DataSourceConfiguration = NULL,
Tags = NULL
)
IndexName |
[required] The name of the place index resource. Requirements:
|
DataSource |
[required] Specifies the geospatial data provider for the new place index. This field is case-sensitive. Enter the valid values as shown. For example, entering Valid values include:
For additional information , see Data providers on the Amazon Location Service developer guide. |
PricingPlan |
No longer used. If included, the only allowed value is |
Description |
The optional description for the place index resource. |
DataSourceConfiguration |
Specifies the data storage option requesting Places. |
Tags |
Applies one or more tags to the place index resource. A tag is a key-value pair that helps you manage, identify, search, and filter your resources. Format: Restrictions:
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.