View source: R/locationservice_operations.R
| locationservice_delete_map | R Documentation |
This operation is no longer current and may be deprecated in the future. We recommend upgrading to the Maps API V2 unless you require Grab data.
See https://www.paws-r-sdk.com/docs/locationservice_delete_map/ for full documentation.
locationservice_delete_map(MapName)
MapName |
[required] The name of the map resource to be deleted. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.