View source: R/locationservice_operations.R
| locationservice_get_map_sprites | R Documentation |
This operation is no longer current and may be deprecated in the future. We recommend upgrading to GetSprites unless you require Grab data.
See https://www.paws-r-sdk.com/docs/locationservice_get_map_sprites/ for full documentation.
locationservice_get_map_sprites(MapName, FileName, Key = NULL)
MapName |
[required] The map resource associated with the sprite file. |
FileName |
[required] The name of the sprite file. Use the following file names for the sprite sheet:
For the JSON document containing image offsets. Use the following file names:
|
Key |
The optional API key to authorize the request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.