View source: R/locationservice_operations.R
| locationservice_get_map_tile | R Documentation |
This operation is no longer current and may be deprecated in the future. We recommend upgrading to GetTile unless you require Grab data.
See https://www.paws-r-sdk.com/docs/locationservice_get_map_tile/ for full documentation.
locationservice_get_map_tile(MapName, Z, X, Y, Key = NULL)
MapName |
[required] The map resource to retrieve the map tiles from. |
Z |
[required] The zoom value for the map tile. |
X |
[required] The X axis value for the map tile. |
Y |
[required] The Y axis value for the map tile. |
Key |
The optional API key to authorize the request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.