View source: R/locationservice_operations.R
| locationservice_list_jobs | R Documentation |
list_jobs retrieves a list of jobs with optional filtering and pagination support.
See https://www.paws-r-sdk.com/docs/locationservice_list_jobs/ for full documentation.
locationservice_list_jobs(Filter = NULL, MaxResults = NULL, NextToken = NULL)
Filter |
An optional structure containing criteria by which to filter job results. |
MaxResults |
Maximum number of jobs to return. |
NextToken |
The pagination token specifying which page of results to return in the response. If no token is provided, the default page is the first page. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.