View source: R/resourceexplorer_operations.R
| resourceexplorer_delete_resource_explorer_setup | R Documentation |
Deletes a Resource Explorer setup configuration. This operation removes indexes and views from the specified Regions or all Regions where Resource Explorer is configured.
See https://www.paws-r-sdk.com/docs/resourceexplorer_delete_resource_explorer_setup/ for full documentation.
resourceexplorer_delete_resource_explorer_setup(
RegionList = NULL,
DeleteInAllRegions = NULL
)
RegionList |
A list of Amazon Web Services Regions from which to delete the Resource Explorer configuration. If not specified, the operation uses the |
DeleteInAllRegions |
Specifies whether to delete Resource Explorer configuration from all Regions where it is currently enabled. If this parameter is set to |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.