View source: R/resourceexplorer_operations.R
| resourceexplorer_get_resource_explorer_setup | R Documentation |
Retrieves the status and details of a Resource Explorer setup operation. This operation returns information about the progress of creating or deleting Resource Explorer configurations across Regions.
See https://www.paws-r-sdk.com/docs/resourceexplorer_get_resource_explorer_setup/ for full documentation.
resourceexplorer_get_resource_explorer_setup(
TaskId,
MaxResults = NULL,
NextToken = NULL
)
TaskId |
[required] The unique identifier of the setup task to retrieve status information for. This ID is returned by |
MaxResults |
The maximum number of Region status results to return in a single response. Valid values are between |
NextToken |
The pagination token from a previous |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.