View source: R/resourceexplorer_operations.R
| resourceexplorer_get_service_index | R Documentation |
Retrieves information about the Resource Explorer index in the current Amazon Web Services Region. This operation returns the ARN and type of the index if one exists.
See https://www.paws-r-sdk.com/docs/resourceexplorer_get_service_index/ for full documentation.
resourceexplorer_get_service_index()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.