View source: R/resourceexplorer_operations.R
| resourceexplorer_list_service_indexes | R Documentation |
Lists all Resource Explorer indexes across the specified Amazon Web Services Regions. This operation returns information about indexes including their ARNs, types, and Regions.
See https://www.paws-r-sdk.com/docs/resourceexplorer_list_service_indexes/ for full documentation.
resourceexplorer_list_service_indexes(
Regions = NULL,
MaxResults = NULL,
NextToken = NULL
)
Regions |
A list of Amazon Web Services Regions to include in the search for indexes. If not specified, indexes from all Regions are returned. |
MaxResults |
The maximum number of index results to return in a single response. Valid values are between |
NextToken |
The pagination token from a previous |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.