View source: R/resourceexplorer_operations.R
| resourceexplorer_list_service_views | R Documentation |
Lists all Resource Explorer service views available in the current Amazon Web Services account. This operation returns the ARNs of available service views.
See https://www.paws-r-sdk.com/docs/resourceexplorer_list_service_views/ for full documentation.
resourceexplorer_list_service_views(MaxResults = NULL, NextToken = NULL)
MaxResults |
The maximum number of service view results to return in a single response. Valid values are between |
NextToken |
The pagination token from a previous |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.