View source: R/resourceexplorer_operations.R
| resourceexplorer_list_streaming_access_for_services | R Documentation |
Returns a list of Amazon Web Services services that have been granted streaming access to your Resource Explorer data. Streaming access allows Amazon Web Services services to receive real-time updates about your resources as they are indexed by Resource Explorer.
See https://www.paws-r-sdk.com/docs/resourceexplorer_list_streaming_access_for_services/ for full documentation.
resourceexplorer_list_streaming_access_for_services(
MaxResults = NULL,
NextToken = NULL
)
MaxResults |
The maximum number of streaming access entries to return in the response. If there are more results available, the response includes a NextToken value that you can use in a subsequent call to get the next set of results. The value must be between 1 and 50. If you don't specify a value, the default is 50. |
NextToken |
The parameter for receiving additional results if you receive a |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.