View source: R/sns_operations.R
| sns_publish_batch | R Documentation |
Publishes up to 10 messages to the specified topic in a single batch. This is a batch version of the publish API. If you try to send more than 10 messages in a single batch request, you will receive a TooManyEntriesInBatchRequest exception.
See https://www.paws-r-sdk.com/docs/sns_publish_batch/ for full documentation.
sns_publish_batch(TopicArn, PublishBatchRequestEntries)
TopicArn |
[required] The Amazon resource name (ARN) of the topic you want to batch publish to. |
PublishBatchRequestEntries |
[required] A list of |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.